@@ -33,6 +33,7 @@ import sklearn.metrics
 
 def select_activity_classifier_on_cell_type_outputs(cell_type_config_file, cell_type_predictions,
                                                     cell_type_to_classifier, default_classifier,
+                                                    unknown_cell_type_action="ignore",
                                                     cell_type_threshold=0.5):
     """
     Allows to create a dictionary that will be passed to CinacPredictor.add_recording() as the model_files_dict
@@ -49,6 +50,9 @@ def select_activity_classifier_on_cell_type_outputs(cell_type_config_file, cell_
         specific activity classifier to a cell type
         default_classifier: (tuple of 3 strings) (model file, weights file, classifier id) that attribute a default
          activity classifier in a cell has no predominant cell type
+        unknown_cell_type_action: (str) Decide what to do when cell type is not in cell_type_to_classifier. Either
+        'ignore' meaning the cell with that cell type won't be predicted, "default" we use the default classifier
+        on it or "exception" then an exception would be raise and the excecution will be aborded
 
     Returns: return a dict compatible with CinacPredictor.add_recording() model_files_dict argument.
     key is a tuple of 3 strings (model file, weights file, classifier id), and value is the cells whose activity
@@ -81,12 +85,20 @@ def select_activity_classifier_on_cell_type_outputs(cell_type_config_file, cell_
             model_files_dict[default_classifier].append(cell)
         else:
             if cell_type_code not in cell_type_to_classifier_encoded:
-                raise Exception(f"Cell type code {cell_type_code} not recognized as a valid cell type, "
+                if unknown_cell_type_action == "ignore":
+                    continue
+                elif unknown_cell_type_action == "default":
+                    if default_classifier not in model_files_dict:
+                        model_files_dict[default_classifier] = []
+                    model_files_dict[default_classifier].append(cell)
+                else:
+                    raise Exception(f"Cell type code {cell_type_code} not recognized as a valid cell type, "
                                 f"using {os.path.basename(cell_type_config_file)}")
-            model_tuple = cell_type_to_classifier_encoded[cell_type_code]
-            if model_tuple not in model_files_dict:
-                model_files_dict[model_tuple] = []
-            model_files_dict[model_tuple].append(cell)
+            else:
+                model_tuple = cell_type_to_classifier_encoded[cell_type_code]
+                if model_tuple not in model_files_dict:
+                    model_files_dict[model_tuple] = []
+                model_files_dict[model_tuple].append(cell)
 
     # Converting cells list as np.array
     for model_tuple, cells in model_files_dict.items():
